﻿using System;
using System.Collections.ObjectModel;
using System.Windows.Forms;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WinForms;

namespace _9313
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;

            GenerateGridShape();
        }

        private void GenerateGridShape()
        {
            InMemoryFeatureLayer userPolygonsLayer = new InMemoryFeatureLayer();

            double rectangleHeight = 20; //height and width of each rectangle
            double rectangleWidth = 20;
            Collection<PolygonShape> rectangleShapes = new Collection<PolygonShape>(); //holds the rectangles converted to polygons
            PointShape anchorPoint = new PointShape(0, 0); //this will be the upper left point of the rectangle
            RectangleShape rectangleShape = new RectangleShape(); //first rectangle shape, other rectangles will be calculated off of this one
            PointShape lowerRight = (PointShape)anchorPoint.CloneDeep();
            lowerRight.TranslateByOffset(rectangleWidth, -rectangleHeight, GeographyUnit.DecimalDegree, DistanceUnit.Meter);
            rectangleShape = new RectangleShape(anchorPoint, lowerRight);
            rectangleShapes.Add(rectangleShape.ToPolygon());

            for (int i = 0; i < 2; i++) //I want a 2x2 grid shape, so four rectangles total
            {
                for (int j = 0; j < 2; j++)
                {
                    if (i == 0 && j == 0) //we already created the first rectangle
                    {
                        //do nothing
                    }
                    else //create the other rectangles
                    {
                        RectangleShape newRectangle = (RectangleShape)rectangleShape.CloneDeep();
                        newRectangle.TranslateByOffset(rectangleWidth * j, -rectangleHeight * i, GeographyUnit.DecimalDegree, DistanceUnit.Meter);
                        rectangleShapes.Add(newRectangle.ToPolygon());
                    }
                }
            }

            MultipolygonShape polygonShape = new MultipolygonShape(rectangleShapes);

            Feature newGrid = new Feature(polygonShape);
            newGrid.ColumnValues.Add("styleName", "EmptyRed2");
            newGrid.ColumnValues.Add("fontStyleName", "Title1");
            newGrid.ColumnValues.Add("Label", newGrid.Id);

            userPolygonsLayer.InternalFeatures.Add(newGrid);

            ValueStyle valueStyle = new ValueStyle();
            valueStyle.ColumnName = "styleName";
            AreaStyle polyStyle = new AreaStyle(new GeoPen(GeoColors.Red), new GeoSolidBrush(GeoColors.Transparent)); //PolyStyle is just a simple area style. Red outline, no fill color
            valueStyle.ValueItems.Add(new ValueItem("EmptyRed2", polyStyle));

            userPolygonsLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(valueStyle);
            userPolygonsLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add(userPolygonsLayer);

            userPolygonsLayer.Open();
            winformsMap1.CurrentExtent = userPolygonsLayer.GetBoundingBox();

            winformsMap1.Overlays.Add(overlay);
            winformsMap1.Refresh();

        }
    }
}